@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
-"POT-Creation-Date: 2002-03-26 13:41-0600\n"
+"POT-Creation-Date: 2002-04-21 16:40-0500\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -51,22 +51,38 @@ msgstr ""
 msgid "File"
 msgstr ""
 
-#: capplet/mtm-view-extensions-selector.c:124 libbackground/applier.c:230
+#: capplet/mtm-view-extensions-selector.c:124 libbackground/applier.c:239
 msgid "Type"
 msgstr ""
 
-#: libbackground/applier.c:231
+#: libbackground/applier.c:240
 msgid ""
 "Type of bg_applier: BG_APPLIER_ROOT for root window or BG_APPLIER_PREVIEW "
 "for preview"
 msgstr ""
 
-#: libbackground/applier.c:398
+#: libbackground/applier.c:247
+msgid "Preview Width"
+msgstr ""
+
+#: libbackground/applier.c:248
+msgid "Width if applier is a preview: Defaults to 64."
+msgstr ""
+
+#: libbackground/applier.c:255
+msgid "Preview Height"
+msgstr ""
+
+#: libbackground/applier.c:256
+msgid "Height if applier is a preview: Defaults to 48."
+msgstr ""
+
+#: libbackground/applier.c:454
 #, c-format
 msgid "Could not load pixbuf \"%s\"; disabling wallpaper."
 msgstr ""
 
-#: libbackground/applier.c:466
+#: libbackground/applier.c:533
 msgid "Disabled"
 msgstr ""
 
@@ -127,7 +143,7 @@ msgid ""
 "background pattern, which appears behind the background image."
 msgstr ""
 
-#: plugins/background/bg-config-gui.c:176
+#: plugins/background/bg-config-gui.c:179
 msgid "Please select a background image"
 msgstr ""
 
